@@ -1,22 +1,22 @@
 /*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of libdvdread.
+ *
+ * libdvdread is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * libdvdread is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- * $Id: ifo_print.c 1135 2008-09-06 21:55:51Z rathann $
- *
+ * You should have received a copy of the GNU General Public License along
+ * with libdvdread; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -25,12 +25,12 @@
 #include <ctype.h>
 #include <assert.h>
 
-#include "ifo_types.h"
-#include "ifo_read.h"
-#include "ifo_print.h"
+#include "dvdread/ifo_types.h"
+#include "dvdread/ifo_read.h"
+#include "dvdread/ifo_print.h"
 
 /* Put this in some other file / package?  It's used in nav_print too. */
-static void ifo_print_time(int level, dvd_time_t *dtime) {
+static void ifo_print_time(dvd_time_t *dtime) {
   const char *rate;
   assert((dtime->hour>>4) < 0xa && (dtime->hour&0xf) < 0xa);
   assert((dtime->minute>>4) < 0x7 && (dtime->minute&0xf) < 0xa);
@@ -38,10 +38,10 @@ static void ifo_print_time(int level, dvd_time_t *dtime) {
   assert((dtime->frame_u&0xf) < 0xa);
 
   printf("%02x:%02x:%02x.%02x",
-	 dtime->hour,
-	 dtime->minute,
-	 dtime->second,
-	 dtime->frame_u & 0x3f);
+         dtime->hour,
+         dtime->minute,
+         dtime->second,
+         dtime->frame_u & 0x3f);
   switch((dtime->frame_u & 0xc0) >> 6) {
   case 1:
     rate = "25.00";
@@ -61,7 +61,7 @@ static void ifo_print_time(int level, dvd_time_t *dtime) {
 }
 
 void dvdread_print_time(dvd_time_t *dtime) {
-  ifo_print_time(5, dtime);
+  ifo_print_time(dtime);
 }
 
 /* Put this in some other file / package?  It's used in nav_print too.
@@ -80,7 +80,7 @@ static void ifo_print_cmd(int row, vm_cmd_t *command) {
   printf("\n");
 }
 
-static void ifo_print_video_attributes(int level, video_attr_t *attr) {
+static void ifo_print_video_attributes(video_attr_t *attr) {
 
   /* The following test is shorter but not correct ISO C,
      memcmp(attr,my_friendly_zeros, sizeof(video_attr_t)) */
@@ -88,10 +88,9 @@ static void ifo_print_video_attributes(int level, video_attr_t *attr) {
      && attr->video_format == 0
      && attr->display_aspect_ratio == 0
      && attr->permitted_df == 0
-     && attr->unknown1 == 0
      && attr->line21_cc_1 == 0
      && attr->line21_cc_2 == 0
-     && attr->video_format == 0
+     && attr->unknown1 == 0
      && attr->letterboxed == 0
      && attr->film_mode == 0) {
     printf("-- Unspecified --");
@@ -131,7 +130,7 @@ static void ifo_print_video_attributes(int level, video_attr_t *attr) {
     printf("(please send a bug report), ");
   }
 
-  // Wide is allways allowed..!!!
+  // Wide is always allowed..!!!
   switch(attr->permitted_df) {
   case 0:
     printf("pan&scan+letterboxed, ");
@@ -149,9 +148,6 @@ static void ifo_print_video_attributes(int level, video_attr_t *attr) {
     printf("(please send a bug report), ");
   }
 
-  printf("U%x, ", attr->unknown1);
-  assert(!attr->unknown1);
-
   if(attr->line21_cc_1 || attr->line21_cc_2) {
     printf("NTSC CC ");
     if(attr->line21_cc_1)
@@ -187,13 +183,16 @@ static void ifo_print_video_attributes(int level, video_attr_t *attr) {
   }
 
   if(attr->film_mode) {
-    printf("film. ");
+    printf("film, ");
   } else {
-    printf("video. "); //camera
+    printf("video, "); //camera
   }
+
+  printf("Unknown1: %x", attr->unknown1);
+
 }
 
-static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
+static void ifo_print_audio_attributes(audio_attr_t *attr) {
 
   if(attr->audio_format == 0
      && attr->multichannel_extension == 0
@@ -201,9 +200,9 @@ static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
      && attr->application_mode == 0
      && attr->quantization == 0
      && attr->sample_frequency == 0
+     && attr->unknown1 == 0
      && attr->channels == 0
      && attr->lang_extension == 0
-     && attr->unknown1 == 0
      && attr->unknown3 == 0) {
     printf("-- Unspecified --");
     return;
@@ -223,31 +222,31 @@ static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
   case 3:
     printf("mpeg2ext ");
     switch(attr->quantization) {
-      case 0:
-        printf("no drc ");
-        break;
-      case 1:
-        printf("drc ");
-        break;
-      default:
-        printf("(please send a bug report) mpeg reserved quant/drc  (%d)", attr->quantization);
+    case 0:
+      printf("no drc ");
+      break;
+    case 1:
+      printf("drc ");
+      break;
+    default:
+      printf("(please send a bug report) mpeg reserved quant/drc  (%d)", attr->quantization);
     }
     break;
   case 4:
     printf("lpcm ");
     switch(attr->quantization) {
-      case 0:
-        printf("16bit ");
-        break;
-      case 1:
-        printf("20bit ");
-        break;
-      case 2:
-        printf("24bit ");
-        break;
-      case 3:
-        printf("(please send a bug report) lpcm reserved quant/drc  (%d)", attr->quantization);
+    case 0:
+      printf("16bit ");
       break;
+    case 1:
+      printf("20bit ");
+      break;
+    case 2:
+      printf("24bit ");
+      break;
+    case 3:
+      printf("(please send a bug report) lpcm reserved quant/drc  (%d)", attr->quantization);
+    break;
     }
     break;
   case 5:
@@ -268,7 +267,8 @@ static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
   switch(attr->lang_type) {
   case 0:
     // not specified
-    assert(attr->lang_code == 0 || attr->lang_code == 0xffff);
+    if(attr->lang_code != 0 && attr->lang_code != 0xffff)
+        printf("Lang_code 0x%x, please send a bug report!", attr->lang_code);
     break;
   case 1:
     printf("%c%c ", attr->lang_code>>8, attr->lang_code & 0xff);
@@ -317,7 +317,7 @@ static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
     break;
   default:
     printf("sample_frequency %i (please send a bug report) ",
-	   attr->sample_frequency);
+           attr->sample_frequency);
   }
 
   printf("%dCh ", attr->channels + 1);
@@ -329,7 +329,7 @@ static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
   case 1: // Normal audio
     printf("Normal Caption ");
     break;
-  case 2: // visually imparied
+  case 2: // visually impaired
     printf("Audio for visually impaired ");
     break;
   case 3: // Directors 1
@@ -343,16 +343,16 @@ static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
     printf("(please send a bug report) ");
   }
 
-  printf("%d ", attr->unknown1);
-  printf("%d ", attr->unknown3);
+  printf("Unknown1: %d ", attr->unknown1);
+  printf("Unknown3: %d ", attr->unknown3);
 }
 
-static void ifo_print_subp_attributes(int level, subp_attr_t *attr) {
+static void ifo_print_subp_attributes(subp_attr_t *attr) {
 
   if(attr->type == 0
-     && attr->lang_code == 0
      && attr->zero1 == 0
      && attr->zero2 == 0
+     && attr->lang_code == 0
      && attr->lang_extension== 0) {
     printf("-- Unspecified --");
     return;
@@ -365,7 +365,7 @@ static void ifo_print_subp_attributes(int level, subp_attr_t *attr) {
     printf("%c%c ", attr->lang_code >> 8, attr->lang_code & 0xff);
   } else {
     printf("%02x%02x ", 0xff & (unsigned)(attr->lang_code >> 8),
-	   0xff & (unsigned)(attr->lang_code & 0xff));
+           0xff & (unsigned)(attr->lang_code & 0xff));
   }
 
   printf("%d ", attr->zero1);
@@ -427,7 +427,7 @@ static void ifo_print_subp_attributes(int level, subp_attr_t *attr) {
 }
 
 
-static void ifo_print_USER_OPS(user_ops_t *user_ops) {
+static void ifoPrint_USER_OPS(user_ops_t *user_ops) {
   uint32_t uops;
   unsigned char *ptr = (unsigned char *)user_ops;
 
@@ -496,14 +496,14 @@ static void ifo_print_USER_OPS(user_ops_t *user_ops) {
 }
 
 
-void ifo_print_VMGI_MAT(vmgi_mat_t *vmgi_mat) {
+static void ifoPrint_VMGI_MAT(vmgi_mat_t *vmgi_mat) {
 
   printf("VMG Identifier: %.12s\n", vmgi_mat->vmg_identifier);
   printf("Last Sector of VMG: %08x\n", vmgi_mat->vmg_last_sector);
   printf("Last Sector of VMGI: %08x\n", vmgi_mat->vmgi_last_sector);
   printf("Specification version number: %01x.%01x\n",
-	 vmgi_mat->specification_version >> 4,
-	 vmgi_mat->specification_version & 0xf);
+         vmgi_mat->specification_version >> 4,
+         vmgi_mat->specification_version & 0xf);
   /* Byte 2 of 'VMG Category' (00xx0000) is the Region Code */
   printf("VMG Category: %08x (Region Code=%02x)\n", vmgi_mat->vmg_category, ((vmgi_mat->vmg_category >> 16) & 0xff) ^0xff);
   printf("VMG Number of Volumes: %i\n", vmgi_mat->vmg_nr_of_volumes);
@@ -515,7 +515,7 @@ void ifo_print_VMGI_MAT(vmgi_mat_t *vmgi_mat) {
   printf("%08x\n", (uint32_t)vmgi_mat->vmg_pos_code);
   printf("End byte of VMGI_MAT: %08x\n", vmgi_mat->vmgi_last_byte);
   printf("Start byte of First Play PGC (FP PGC): %08x\n",
-	 vmgi_mat->first_play_pgc);
+         vmgi_mat->first_play_pgc);
   printf("Start sector of VMGM_VOBS: %08x\n", vmgi_mat->vmgm_vobs);
   printf("Start sector of TT_SRPT: %08x\n", vmgi_mat->tt_srpt);
   printf("Start sector of VMGM_PGCI_UT: %08x\n", vmgi_mat->vmgm_pgci_ut);
@@ -524,36 +524,36 @@ void ifo_print_VMGI_MAT(vmgi_mat_t *vmgi_mat) {
   printf("Start sector of TXTDT_MG: %08x\n", vmgi_mat->txtdt_mgi);
   printf("Start sector of VMGM_C_ADT: %08x\n", vmgi_mat->vmgm_c_adt);
   printf("Start sector of VMGM_VOBU_ADMAP: %08x\n",
-	 vmgi_mat->vmgm_vobu_admap);
+         vmgi_mat->vmgm_vobu_admap);
   printf("Video attributes of VMGM_VOBS: ");
-  ifo_print_video_attributes(5, &vmgi_mat->vmgm_video_attr);
+  ifo_print_video_attributes(&vmgi_mat->vmgm_video_attr);
   printf("\n");
   printf("VMGM Number of Audio attributes: %i\n",
-	 vmgi_mat->nr_of_vmgm_audio_streams);
+         vmgi_mat->nr_of_vmgm_audio_streams);
   if(vmgi_mat->nr_of_vmgm_audio_streams > 0) {
     printf("\tstream %i status: ", 1);
-    ifo_print_audio_attributes(5, &vmgi_mat->vmgm_audio_attr);
+    ifo_print_audio_attributes(&vmgi_mat->vmgm_audio_attr);
     printf("\n");
   }
   printf("VMGM Number of Sub-picture attributes: %i\n",
-	 vmgi_mat->nr_of_vmgm_subp_streams);
+         vmgi_mat->nr_of_vmgm_subp_streams);
   if(vmgi_mat->nr_of_vmgm_subp_streams > 0) {
     printf("\tstream %2i status: ", 1);
-    ifo_print_subp_attributes(5, &vmgi_mat->vmgm_subp_attr);
+    ifo_print_subp_attributes(&vmgi_mat->vmgm_subp_attr);
     printf("\n");
   }
 }
 
 
-void ifo_print_VTSI_MAT(vtsi_mat_t *vtsi_mat) {
+static void ifoPrint_VTSI_MAT(vtsi_mat_t *vtsi_mat) {
   int i;
 
   printf("VTS Identifier: %.12s\n", vtsi_mat->vts_identifier);
   printf("Last Sector of VTS: %08x\n", vtsi_mat->vts_last_sector);
   printf("Last Sector of VTSI: %08x\n", vtsi_mat->vtsi_last_sector);
   printf("Specification version number: %01x.%01x\n",
-	 vtsi_mat->specification_version>>4,
-	 vtsi_mat->specification_version&0xf);
+         vtsi_mat->specification_version>>4,
+         vtsi_mat->specification_version&0xf);
   printf("VTS Category: %08x\n", vtsi_mat->vts_category);
   printf("End byte of VTSI_MAT: %08x\n", vtsi_mat->vtsi_last_byte);
   printf("Start sector of VTSM_VOBS:  %08x\n", vtsi_mat->vtsm_vobs);
@@ -568,48 +568,48 @@ void ifo_print_VTSI_MAT(vtsi_mat_t *vtsi_mat) {
   printf("Start sector of VTS_VOBU_ADMAP:  %08x\n", vtsi_mat->vts_vobu_admap);
 
   printf("Video attributes of VTSM_VOBS: ");
-  ifo_print_video_attributes(5, &vtsi_mat->vtsm_video_attr);
+  ifo_print_video_attributes(&vtsi_mat->vtsm_video_attr);
   printf("\n");
 
   printf("VTSM Number of Audio attributes: %i\n",
-	 vtsi_mat->nr_of_vtsm_audio_streams);
+         vtsi_mat->nr_of_vtsm_audio_streams);
   if(vtsi_mat->nr_of_vtsm_audio_streams > 0) {
     printf("\tstream %i status: ", 1);
-    ifo_print_audio_attributes(5, &vtsi_mat->vtsm_audio_attr);
+    ifo_print_audio_attributes(&vtsi_mat->vtsm_audio_attr);
     printf("\n");
   }
 
   printf("VTSM Number of Sub-picture attributes: %i\n",
-	 vtsi_mat->nr_of_vtsm_subp_streams);
+         vtsi_mat->nr_of_vtsm_subp_streams);
   if(vtsi_mat->nr_of_vtsm_subp_streams > 0) {
     printf("\tstream %2i status: ", 1);
-    ifo_print_subp_attributes(5, &vtsi_mat->vtsm_subp_attr);
+    ifo_print_subp_attributes(&vtsi_mat->vtsm_subp_attr);
     printf("\n");
   }
 
   printf("Video attributes of VTS_VOBS: ");
-  ifo_print_video_attributes(5, &vtsi_mat->vts_video_attr);
+  ifo_print_video_attributes(&vtsi_mat->vts_video_attr);
   printf("\n");
 
   printf("VTS Number of Audio attributes: %i\n",
-	 vtsi_mat->nr_of_vts_audio_streams);
+         vtsi_mat->nr_of_vts_audio_streams);
   for(i = 0; i < vtsi_mat->nr_of_vts_audio_streams; i++) {
     printf("\tstream %i status: ", i);
-    ifo_print_audio_attributes(5, &vtsi_mat->vts_audio_attr[i]);
+    ifo_print_audio_attributes(&vtsi_mat->vts_audio_attr[i]);
     printf("\n");
   }
 
   printf("VTS Number of Subpicture attributes: %i\n",
-	 vtsi_mat->nr_of_vts_subp_streams);
+         vtsi_mat->nr_of_vts_subp_streams);
   for(i = 0; i < vtsi_mat->nr_of_vts_subp_streams; i++) {
     printf("\tstream %2i status: ", i);
-    ifo_print_subp_attributes(5, &vtsi_mat->vts_subp_attr[i]);
+    ifo_print_subp_attributes(&vtsi_mat->vts_subp_attr[i]);
     printf("\n");
   }
 }
 
 
-static void ifo_print_PGC_COMMAND_TBL(pgc_command_tbl_t *cmd_tbl) {
+static void ifoPrint_PGC_COMMAND_TBL(pgc_command_tbl_t *cmd_tbl) {
   int i;
 
   if(cmd_tbl == NULL) {
@@ -634,7 +634,7 @@ static void ifo_print_PGC_COMMAND_TBL(pgc_command_tbl_t *cmd_tbl) {
 }
 
 
-static void ifo_print_PGC_PROGRAM_MAP(pgc_program_map_t *program_map, int nr) {
+static void ifoPrint_PGC_PROGRAM_MAP(pgc_program_map_t *program_map, int nr) {
   int i;
 
   if(program_map == NULL) {
@@ -648,7 +648,7 @@ static void ifo_print_PGC_PROGRAM_MAP(pgc_program_map_t *program_map, int nr) {
 }
 
 
-static void ifo_print_CELL_PLAYBACK(cell_playback_t *cell_playback, int nr) {
+static void ifoPrint_CELL_PLAYBACK(cell_playback_t *cell_playback, int nr) {
   int i;
 
   if(cell_playback == NULL) {
@@ -666,28 +666,28 @@ static void ifo_print_CELL_PLAYBACK(cell_playback_t *cell_playback, int nr) {
       const char *s;
       switch(cell_playback[i].block_mode) {
       case 0:
-	s = "not a"; break;
+        s = "not a"; break;
       case 1:
-	s = "the first"; break;
+        s = "the first"; break;
       case 2:
       default:
-	s = ""; break;
+        s = ""; break;
       case 3:
-	s = "last"; break;
+        s = "last"; break;
       }
       printf("%s cell in the block ", s);
 
       switch(cell_playback[i].block_type) {
       case 0:
-	printf("not part of the block ");
-	break;
+        printf("not part of the block ");
+        break;
       case 1:
-	printf("angle block ");
-	break;
+        printf("angle block ");
+        break;
       case 2:
       case 3:
-	printf("(send bug repport) ");
-	break;
+        printf("(send bug report) ");
+        break;
       }
     }
     if(cell_playback[i].seamless_play)
@@ -710,15 +710,15 @@ static void ifo_print_CELL_PLAYBACK(cell_playback_t *cell_playback, int nr) {
       printf("cell command %d", cell_playback[i].cell_cmd_nr);
 
     printf("\n\tStart sector: %08x\tFirst ILVU end  sector: %08x\n",
-	   cell_playback[i].first_sector,
-	   cell_playback[i].first_ilvu_end_sector);
+           cell_playback[i].first_sector,
+           cell_playback[i].first_ilvu_end_sector);
     printf("\tEnd   sector: %08x\tLast VOBU start sector: %08x\n",
-	   cell_playback[i].last_sector,
-	   cell_playback[i].last_vobu_start_sector);
+           cell_playback[i].last_sector,
+           cell_playback[i].last_vobu_start_sector);
   }
 }
 
-static void ifo_print_CELL_POSITION(cell_position_t *cell_position, int nr) {
+static void ifoPrint_CELL_POSITION(cell_position_t *cell_position, int nr) {
   int i;
 
   if(cell_position == NULL) {
@@ -728,12 +728,12 @@ static void ifo_print_CELL_POSITION(cell_position_t *cell_position, int nr) {
 
   for(i=0;i<nr;i++) {
     printf("Cell: %3i has VOB ID: %3i, Cell ID: %3i\n", i + 1,
-	   cell_position[i].vob_id_nr, cell_position[i].cell_nr);
+           cell_position[i].vob_id_nr, cell_position[i].cell_nr);
   }
 }
 
 
-void ifo_print_PGC(pgc_t *pgc) {
+static void ifoPrint_PGC(pgc_t *pgc) {
   int i;
 
   if (!pgc) {
@@ -748,23 +748,23 @@ void ifo_print_PGC(pgc_t *pgc) {
 
   /* If no programs/no time then does this mean anything? */
   printf("Prohibited user operations: ");
-  ifo_print_USER_OPS(&pgc->prohibited_ops);
+  ifoPrint_USER_OPS(&pgc->prohibited_ops);
 
-    for(i = 0; i < 8; i++) {
-      if(pgc->audio_control[i] & 0x8000) { /* The 'is present' bit */
-	printf("Audio stream %i control: %04x\n",
-	       i, pgc->audio_control[i]);
-      }
+  for(i = 0; i < 8; i++) {
+    if(pgc->audio_control[i] & 0x8000) { /* The 'is present' bit */
+      printf("Audio stream %i control: %04x\n",
+             i, pgc->audio_control[i]);
     }
+  }
 
   for(i = 0; i < 32; i++) {
     if(pgc->subp_control[i] & 0x80000000) { /* The 'is present' bit */
       printf("Subpicture stream %2i control: %08x: 4:3=%d, Wide=%d, Letterbox=%d, Pan-Scan=%d\n",
-	     i, pgc->subp_control[i],
-	     (pgc->subp_control[i] >>24) & 0x1f,
-	     (pgc->subp_control[i] >>16) & 0x1f,
-	     (pgc->subp_control[i] >>8) & 0x1f,
-	     (pgc->subp_control[i] ) & 0x1f);
+             i, pgc->subp_control[i],
+             (pgc->subp_control[i] >>24) & 0x1f,
+             (pgc->subp_control[i] >>16) & 0x1f,
+             (pgc->subp_control[i] >>8) & 0x1f,
+             (pgc->subp_control[i] ) & 0x1f);
     }
   }
 
@@ -782,32 +782,32 @@ void ifo_print_PGC(pgc_t *pgc) {
     }
   }
 
-  /* Memmory offsets to div. tables. */
-  ifo_print_PGC_COMMAND_TBL(pgc->command_tbl);
-  ifo_print_PGC_PROGRAM_MAP(pgc->program_map, pgc->nr_of_programs);
-  ifo_print_CELL_PLAYBACK(pgc->cell_playback, pgc->nr_of_cells);
-  ifo_print_CELL_POSITION(pgc->cell_position, pgc->nr_of_cells);
+  /* Memory offsets to div. tables. */
+  ifoPrint_PGC_COMMAND_TBL(pgc->command_tbl);
+  ifoPrint_PGC_PROGRAM_MAP(pgc->program_map, pgc->nr_of_programs);
+  ifoPrint_CELL_PLAYBACK(pgc->cell_playback, pgc->nr_of_cells);
+  ifoPrint_CELL_POSITION(pgc->cell_position, pgc->nr_of_cells);
 }
 
 
-void ifo_print_TT_SRPT(tt_srpt_t *tt_srpt) {
+static void ifoPrint_TT_SRPT(tt_srpt_t *tt_srpt) {
   int i;
 
   printf("Number of TitleTrack search pointers: %i\n",
-	 tt_srpt->nr_of_srpts);
+         tt_srpt->nr_of_srpts);
   for(i=0;i<tt_srpt->nr_of_srpts;i++) {
     printf("Title Track index %i\n", i + 1);
     printf("\tTitle set number (VTS): %i",
-	   tt_srpt->title[i].title_set_nr);
+           tt_srpt->title[i].title_set_nr);
     printf("\tVTS_TTN: %i\n", tt_srpt->title[i].vts_ttn);
     printf("\tNumber of PTTs: %i\n", tt_srpt->title[i].nr_of_ptts);
     printf("\tNumber of angles: %i\n",
-	   tt_srpt->title[i].nr_of_angles);
+           tt_srpt->title[i].nr_of_angles);
 
     printf("\tTitle playback type: (%02x)\n",
-	   *(uint8_t *)&(tt_srpt->title[i].pb_ty));
+           *(uint8_t *)&(tt_srpt->title[i].pb_ty));
     printf("\t\t%s\n",
-       tt_srpt->title[i].pb_ty.multi_or_random_pgc_title ? "Random or Shuffle" : "Sequencial");
+           tt_srpt->title[i].pb_ty.multi_or_random_pgc_title ? "Random or Shuffle" : "Sequential");
     if (tt_srpt->title[i].pb_ty.jlc_exists_in_cell_cmd) printf("\t\tJump/Link/Call exists in cell cmd\n");
     if (tt_srpt->title[i].pb_ty.jlc_exists_in_prepost_cmd) printf("\t\tJump/Link/Call exists in pre/post cmd\n");
     if (tt_srpt->title[i].pb_ty.jlc_exists_in_button_cmd) printf("\t\tJump/Link/Call exists in button cmd\n");
@@ -816,24 +816,24 @@ void ifo_print_TT_SRPT(tt_srpt_t *tt_srpt) {
     printf("\t\tChapter search or play:%d\n", tt_srpt->title[i].pb_ty.chapter_search_or_play);
 
     printf("\tParental ID field: %04x\n",
-	   tt_srpt->title[i].parental_id);
+           tt_srpt->title[i].parental_id);
     printf("\tTitle set starting sector %08x\n",
-	   tt_srpt->title[i].title_set_sector);
+           tt_srpt->title[i].title_set_sector);
   }
 }
 
 
-void ifo_print_VTS_PTT_SRPT(vts_ptt_srpt_t *vts_ptt_srpt) {
+static void ifoPrint_VTS_PTT_SRPT(vts_ptt_srpt_t *vts_ptt_srpt) {
   int i, j;
   printf(" nr_of_srpts %i last byte %i\n",
-	 vts_ptt_srpt->nr_of_srpts,
-	 vts_ptt_srpt->last_byte);
+         vts_ptt_srpt->nr_of_srpts,
+         vts_ptt_srpt->last_byte);
   for(i=0;i<vts_ptt_srpt->nr_of_srpts;i++) {
     for(j=0;j<vts_ptt_srpt->title[i].nr_of_ptts;j++) {
       printf("VTS_PTT_SRPT - Title %3i part %3i: PGC: %3i PG: %3i\n",
-	     i + 1, j + 1,
-	     vts_ptt_srpt->title[i].ptt[j].pgcn,
-	     vts_ptt_srpt->title[i].ptt[j].pgn );
+             i + 1, j + 1,
+             vts_ptt_srpt->title[i].ptt[j].pgcn,
+             vts_ptt_srpt->title[i].ptt[j].pgn );
     }
   }
 }
@@ -844,7 +844,7 @@ static void hexdump(uint8_t *ptr, int len) {
     printf("%02x ", *ptr++);
 }
 
-void ifo_print_PTL_MAIT(ptl_mait_t *ptl_mait) {
+static void ifoPrint_PTL_MAIT(ptl_mait_t *ptl_mait) {
   int i, j;
 
   printf("Number of Countries: %i\n", ptl_mait->nr_of_countries);
@@ -853,8 +853,8 @@ void ifo_print_PTL_MAIT(ptl_mait_t *ptl_mait) {
 
   for(i = 0; i < ptl_mait->nr_of_countries; i++) {
     printf("Country code: %c%c\n",
-	   ptl_mait->countries[i].country_code >> 8,
-	   ptl_mait->countries[i].country_code & 0xff);
+           ptl_mait->countries[i].country_code >> 8,
+           ptl_mait->countries[i].country_code & 0xff);
     /*
       printf("Start byte: %04x %i\n",
       ptl_mait->countries[i].pf_ptl_mai_start_byte,
@@ -866,14 +866,14 @@ void ifo_print_PTL_MAIT(ptl_mait_t *ptl_mait) {
        If it is for the menu it probably the first entry.  */
     for(j=0;j<8;j++) {
       hexdump( (uint8_t *)ptl_mait->countries - PTL_MAIT_COUNTRY_SIZE
-	       + ptl_mait->countries[i].pf_ptl_mai_start_byte
-	       + j*(ptl_mait->nr_of_vtss+1)*2, (ptl_mait->nr_of_vtss+1)*2);
+               + ptl_mait->countries[i].pf_ptl_mai_start_byte
+               + j*(ptl_mait->nr_of_vtss+1)*2, (ptl_mait->nr_of_vtss+1)*2);
       printf("\n");
     }
   }
 }
 
-void ifo_print_VTS_TMAPT(vts_tmapt_t *vts_tmapt) {
+static void ifoPrint_VTS_TMAPT(vts_tmapt_t *vts_tmapt) {
   unsigned int timeunit;
   int i, j;
 
@@ -896,7 +896,7 @@ void ifo_print_VTS_TMAPT(vts_tmapt_t *vts_tmapt) {
   }
 }
 
-void ifo_print_C_ADT(c_adt_t *c_adt) {
+static void ifoPrint_C_ADT(c_adt_t *c_adt) {
   int i, entries;
 
   printf("Number of VOBs in this VOBS: %i\n", c_adt->nr_of_vobs);
@@ -905,25 +905,25 @@ void ifo_print_C_ADT(c_adt_t *c_adt) {
 
   for(i = 0; i < entries; i++) {
     printf("VOB ID: %3i, Cell ID: %3i   ",
-	   c_adt->cell_adr_table[i].vob_id, c_adt->cell_adr_table[i].cell_id);
+           c_adt->cell_adr_table[i].vob_id, c_adt->cell_adr_table[i].cell_id);
     printf("Sector (first): 0x%08x   (last): 0x%08x\n",
-	   c_adt->cell_adr_table[i].start_sector,
-	   c_adt->cell_adr_table[i].last_sector);
+           c_adt->cell_adr_table[i].start_sector,
+           c_adt->cell_adr_table[i].last_sector);
   }
 }
 
 
-void ifo_print_VOBU_ADMAP(vobu_admap_t *vobu_admap) {
+static void ifoPrint_VOBU_ADMAP(vobu_admap_t *vobu_admap) {
   int i, entries;
 
   entries = (vobu_admap->last_byte + 1 - VOBU_ADMAP_SIZE)/4;
   for(i = 0; i < entries; i++) {
     printf("VOBU %5i  First sector: 0x%08x\n", i + 1,
-	   vobu_admap->vobu_start_sectors[i]);
+           vobu_admap->vobu_start_sectors[i]);
   }
 }
 
-const char *ifo_print_menu_name(int type) {
+static const char *ifo_print_menu_name(int type) {
   const char *menu_name;
   menu_name="";
   switch (type) {
@@ -953,7 +953,7 @@ const char *ifo_print_menu_name(int type) {
 }
 
 /* pgc_type=1 for menu, 0 for title. */
-void ifo_print_PGCIT(pgcit_t *pgcit, int pgc_type) {
+static void ifoPrint_PGCIT(pgcit_t *pgcit, int pgc_type) {
   int i;
 
   printf("\nNumber of Program Chains: %3i\n", pgcit->nr_of_pgci_srp);
@@ -961,31 +961,31 @@ void ifo_print_PGCIT(pgcit_t *pgcit, int pgc_type) {
     printf("\nProgram (PGC): %3i\n", i + 1);
     if (pgc_type) {
        printf("PGC Category: Entry PGC %d, Menu Type=0x%02x:%s (Entry id 0x%02x), ",
-            pgcit->pgci_srp[i].entry_id >> 7,
-            pgcit->pgci_srp[i].entry_id & 0xf,
-            ifo_print_menu_name(pgcit->pgci_srp[i].entry_id & 0xf),
-            pgcit->pgci_srp[i].entry_id);
+              pgcit->pgci_srp[i].entry_id >> 7,
+              pgcit->pgci_srp[i].entry_id & 0xf,
+              ifo_print_menu_name(pgcit->pgci_srp[i].entry_id & 0xf),
+              pgcit->pgci_srp[i].entry_id);
     } else {
        printf("PGC Category: %s VTS_TTN:0x%02x (Entry id 0x%02x), ",
-            pgcit->pgci_srp[i].entry_id >> 7 ? "At Start of" : "During",
-            pgcit->pgci_srp[i].entry_id & 0xf,
-            pgcit->pgci_srp[i].entry_id);
+              pgcit->pgci_srp[i].entry_id >> 7 ? "At Start of" : "During",
+              pgcit->pgci_srp[i].entry_id & 0xf,
+              pgcit->pgci_srp[i].entry_id);
     }
     printf("Parental ID mask 0x%04x\n", pgcit->pgci_srp[i].ptl_id_mask);
-    ifo_print_PGC(pgcit->pgci_srp[i].pgc);
+    ifoPrint_PGC(pgcit->pgci_srp[i].pgc);
   }
 }
 
 
-void ifo_print_PGCI_UT(pgci_ut_t *pgci_ut) {
+static void ifoPrint_PGCI_UT(pgci_ut_t *pgci_ut) {
   int i, menu;
 
   printf("Number of Menu Language Units (PGCI_LU): %3i\n", pgci_ut->nr_of_lus);
   for(i = 0; i < pgci_ut->nr_of_lus; i++) {
     printf("\nMenu Language Unit %d\n", i+1);
     printf("\nMenu Language Code: %c%c\n",
-	   pgci_ut->lu[i].lang_code >> 8,
-	   pgci_ut->lu[i].lang_code & 0xff);
+           pgci_ut->lu[i].lang_code >> 8,
+           pgci_ut->lu[i].lang_code & 0xff);
 
     menu = pgci_ut->lu[i].exists;
     printf("Menu Existence: %02x: ", menu);
@@ -1017,62 +1017,62 @@ void ifo_print_PGCI_UT(pgci_ut_t *pgci_ut) {
       menu^=0x08;
     }
     printf("\n");
-    ifo_print_PGCIT(pgci_ut->lu[i].pgcit, 1);
+    ifoPrint_PGCIT(pgci_ut->lu[i].pgcit, 1);
   }
 }
 
 
-static void ifo_print_VTS_ATTRIBUTES(vts_attributes_t *vts_attributes) {
+static void ifoPrint_VTS_ATTRIBUTES(vts_attributes_t *vts_attributes) {
   int i;
 
   printf("VTS_CAT Application type: %08x\n", vts_attributes->vts_cat);
 
   printf("Video attributes of VTSM_VOBS: ");
-  ifo_print_video_attributes(5, &vts_attributes->vtsm_vobs_attr);
+  ifo_print_video_attributes(&vts_attributes->vtsm_vobs_attr);
   printf("\n");
   printf("Number of Audio streams: %i\n",
-	 vts_attributes->nr_of_vtsm_audio_streams);
+         vts_attributes->nr_of_vtsm_audio_streams);
   if(vts_attributes->nr_of_vtsm_audio_streams > 0) {
     printf("\tstream %i attributes: ", 1);
-    ifo_print_audio_attributes(5, &vts_attributes->vtsm_audio_attr);
+    ifo_print_audio_attributes(&vts_attributes->vtsm_audio_attr);
     printf("\n");
   }
   printf("Number of Subpicture streams: %i\n",
-	 vts_attributes->nr_of_vtsm_subp_streams);
+         vts_attributes->nr_of_vtsm_subp_streams);
   if(vts_attributes->nr_of_vtsm_subp_streams > 0) {
     printf("\tstream %2i attributes: ", 1);
-    ifo_print_subp_attributes(5, &vts_attributes->vtsm_subp_attr);
+    ifo_print_subp_attributes(&vts_attributes->vtsm_subp_attr);
     printf("\n");
   }
 
   printf("Video attributes of VTSTT_VOBS: ");
-  ifo_print_video_attributes(5, &vts_attributes->vtstt_vobs_video_attr);
+  ifo_print_video_attributes(&vts_attributes->vtstt_vobs_video_attr);
   printf("\n");
   printf("Number of Audio streams: %i\n",
-	 vts_attributes->nr_of_vtstt_audio_streams);
+         vts_attributes->nr_of_vtstt_audio_streams);
   for(i = 0; i < vts_attributes->nr_of_vtstt_audio_streams; i++) {
     printf("\tstream %i attributes: ", i);
-    ifo_print_audio_attributes(5, &vts_attributes->vtstt_audio_attr[i]);
+    ifo_print_audio_attributes(&vts_attributes->vtstt_audio_attr[i]);
     printf("\n");
   }
 
   printf("Number of Subpicture streams: %i\n",
-	 vts_attributes->nr_of_vtstt_subp_streams);
+         vts_attributes->nr_of_vtstt_subp_streams);
   for(i = 0; i < vts_attributes->nr_of_vtstt_subp_streams; i++) {
     printf("\tstream %2i attributes: ", i);
-    ifo_print_subp_attributes(5, &vts_attributes->vtstt_subp_attr[i]);
+    ifo_print_subp_attributes(&vts_attributes->vtstt_subp_attr[i]);
     printf("\n");
   }
 }
 
 
-void ifo_print_VTS_ATRT(vts_atrt_t *vts_atrt) {
+static void ifoPrint_VTS_ATRT(vts_atrt_t *vts_atrt) {
   int i;
 
   printf("Number of Video Title Sets: %3i\n", vts_atrt->nr_of_vtss);
   for(i = 0; i < vts_atrt->nr_of_vtss; i++) {
     printf("\nVideo Title Set %i\n", i + 1);
-    ifo_print_VTS_ATTRIBUTES(&vts_atrt->vts[i]);
+    ifoPrint_VTS_ATTRIBUTES(&vts_atrt->vts[i]);
   }
 }
 
@@ -1090,37 +1090,37 @@ void ifo_print(dvd_reader_t *dvd, int title) {
   if(ifohandle->vmgi_mat) {
 
     printf("VMG top level\n-------------\n");
-    ifo_print_VMGI_MAT(ifohandle->vmgi_mat);
+    ifoPrint_VMGI_MAT(ifohandle->vmgi_mat);
 
     printf("\nFirst Play PGC\n--------------\n");
     if(ifohandle->first_play_pgc)
-      ifo_print_PGC(ifohandle->first_play_pgc);
+      ifoPrint_PGC(ifohandle->first_play_pgc);
     else
       printf("No First Play PGC present\n");
 
     printf("\nTitle Track search pointer table\n");
     printf(  "------------------------------------------------\n");
-    ifo_print_TT_SRPT(ifohandle->tt_srpt);
+    ifoPrint_TT_SRPT(ifohandle->tt_srpt);
 
     printf("\nMenu PGCI Unit table\n");
     printf(  "--------------------\n");
     if(ifohandle->pgci_ut) {
-      ifo_print_PGCI_UT(ifohandle->pgci_ut);
+      ifoPrint_PGCI_UT(ifohandle->pgci_ut);
     } else {
       printf("No PGCI Unit table present\n");
     }
 
-    printf("\nParental Manegment Information table\n");
+    printf("\nParental Management Information table\n");
     printf(  "------------------------------------\n");
     if(ifohandle->ptl_mait) {
-      ifo_print_PTL_MAIT(ifohandle->ptl_mait);
+      ifoPrint_PTL_MAIT(ifohandle->ptl_mait);
     } else {
       printf("No Parental Management Information present\n");
     }
 
     printf("\nVideo Title Set Attribute Table\n");
     printf(  "-------------------------------\n");
-    ifo_print_VTS_ATRT(ifohandle->vts_atrt);
+    ifoPrint_VTS_ATRT(ifohandle->vts_atrt);
 
     printf("\nText Data Manager Information\n");
     printf(  "-----------------------------\n");
@@ -1130,18 +1130,18 @@ void ifo_print(dvd_reader_t *dvd, int title) {
       printf("No Text Data Manager Information present\n");
     }
 
-    printf("\nMenu Cell Adress table\n");
+    printf("\nMenu Cell Address table\n");
     printf(  "-----------------\n");
     if(ifohandle->menu_c_adt) {
-      ifo_print_C_ADT(ifohandle->menu_c_adt);
+      ifoPrint_C_ADT(ifohandle->menu_c_adt);
     } else {
-      printf("No Menu Cell Adress table present\n");
+      printf("No Menu Cell Address table present\n");
     }
 
     printf("\nVideo Manager Menu VOBU address map\n");
     printf(  "-----------------\n");
     if(ifohandle->menu_vobu_admap) {
-      ifo_print_VOBU_ADMAP(ifohandle->menu_vobu_admap);
+      ifoPrint_VOBU_ADMAP(ifohandle->menu_vobu_admap);
     } else {
       printf("No Menu VOBU address map present\n");
     }
@@ -1151,20 +1151,20 @@ void ifo_print(dvd_reader_t *dvd, int title) {
   if(ifohandle->vtsi_mat) {
 
     printf("VTS top level\n-------------\n");
-    ifo_print_VTSI_MAT(ifohandle->vtsi_mat);
+    ifoPrint_VTSI_MAT(ifohandle->vtsi_mat);
 
     printf("\nPart of Title Track search pointer table\n");
     printf(  "----------------------------------------------\n");
-    ifo_print_VTS_PTT_SRPT(ifohandle->vts_ptt_srpt);
+    ifoPrint_VTS_PTT_SRPT(ifohandle->vts_ptt_srpt);
 
     printf("\nPGCI Unit table\n");
     printf(  "--------------------\n");
-    ifo_print_PGCIT(ifohandle->vts_pgcit, 0);
+    ifoPrint_PGCIT(ifohandle->vts_pgcit, 0);
 
     printf("\nMenu PGCI Unit table\n");
     printf(  "--------------------\n");
     if(ifohandle->pgci_ut) {
-      ifo_print_PGCI_UT(ifohandle->pgci_ut);
+      ifoPrint_PGCI_UT(ifohandle->pgci_ut);
     } else {
       printf("No Menu PGCI Unit table present\n");
     }
@@ -1172,80 +1172,35 @@ void ifo_print(dvd_reader_t *dvd, int title) {
     printf("\nVTS Time Map table\n");
     printf(  "-----------------\n");
     if(ifohandle->vts_tmapt) {
-      ifo_print_VTS_TMAPT(ifohandle->vts_tmapt);
+      ifoPrint_VTS_TMAPT(ifohandle->vts_tmapt);
     } else {
       printf("No VTS Time Map table present\n");
     }
 
-    printf("\nMenu Cell Adress table\n");
+    printf("\nMenu Cell Address table\n");
     printf(  "-----------------\n");
     if(ifohandle->menu_c_adt) {
-      ifo_print_C_ADT(ifohandle->menu_c_adt);
+      ifoPrint_C_ADT(ifohandle->menu_c_adt);
     } else {
-      printf("No Cell Adress table present\n");
+      printf("No Cell Address table present\n");
     }
 
     printf("\nVideo Title Set Menu VOBU address map\n");
     printf(  "-----------------\n");
     if(ifohandle->menu_vobu_admap) {
-      ifo_print_VOBU_ADMAP(ifohandle->menu_vobu_admap);
+      ifoPrint_VOBU_ADMAP(ifohandle->menu_vobu_admap);
     } else {
       printf("No Menu VOBU address map present\n");
     }
 
-    printf("\nCell Adress table\n");
+    printf("\nCell Address table\n");
     printf(  "-----------------\n");
-    ifo_print_C_ADT(ifohandle->vts_c_adt);
+    ifoPrint_C_ADT(ifohandle->vts_c_adt);
 
     printf("\nVideo Title Set VOBU address map\n");
     printf(  "-----------------\n");
-    ifo_print_VOBU_ADMAP(ifohandle->vts_vobu_admap);
+    ifoPrint_VOBU_ADMAP(ifohandle->vts_vobu_admap);
   }
 
   ifoClose(ifohandle);
 }
-
-/*
- * $Log$
- * Revision 1.3  2004/10/22 11:36:19  jcdutton
- * Stop seg fault when using ifo_dump.
- *
- * Revision 1.2  2004/09/27 12:24:01  jcdutton
- * Add extra info to printout when using ifo_dump.
- *
- * Revision 1.1  2004/01/11 21:43:13  mroi
- * big build system changes
- *  * cleaned up all Makefiles and added a Makefile.common
- *  * added relchk script
- *  * moved libdvdread files to a dvdread subdir
- *  * moved DVD VM to a vm subdir
- *  * removed unused code in read_cache.c
- *
- * Revision 1.4  2004/01/01 15:13:13  jcdutton
- * Put ifo_print.c and .h back in.
- *
- * Revision 1.7  2003/04/28 15:17:17  jcdutton
- * Update ifodump to work with new libdvdnav cvs, instead of needing libdvdread.
- *
- * Revision 1.6  2003/04/05 22:49:04  jcdutton
- * Update with more info from the latest libdvdread.
- *
- * Revision 1.5  2003/04/05 13:03:49  jcdutton
- * Small updates.
- *
- * Revision 1.4  2003/04/01 08:01:03  jcdutton
- * Add VTS Time map display. Requires libdvdread 0.9.4. The same version that comes with xine.
- *
- * Revision 1.3  2003/03/14 15:49:18  mroi
- * adjust to new libdvdread version
- *
- * Revision 1.2  2002/08/30 05:12:33  jcdutton
- * Minor update now that I know what PGC Entry IDs are for.
- *
- * Revision 1.1.1.1  2002/08/28 09:48:35  jcdutton
- * Initial import into CVS.
- *
- *
- *
- */
-
